Slider — Kivy v1.0.1-dev documentation

# Slider

The slider is a widget that look like a scrollbar, and support horizontal/vertical orientation, minimum/maximum value, and a default value.

For example, create a slider from -100 to 100, default to 25

    from kivy.uix.slider import Slider
    s = Slider(min=-100, max=100, value=25)

Or for creating a vertical slider

    from kivy.uix.slider import Slider
    s = Slider(orientation='vertical')

class `kivy.uix.slider.` `Slider`(**kwargs)

  Bases: `kivy.uix.widget.Widget`

  Class for creating Slider widget.

  Check module documentation for more details.

  `max`

    Maximum value allowed for `value`.

    `max` is a `NumericProperty`, default to 100.

  `min`

    Minimum value allowed for `value`.

    `min` is a `NumericProperty`, default to 0.

  `orientation`

    Orientation of the slider.

    `orientation` is an `OptionProperty`, default to ‘horizontal’. Can take a value of ‘vertical’ or ‘horizontal’.

  `padding`

    Padding of the slider. The padding is used for graphical representation and interaction. It prevent the cursor to go out of the bounds of the slider bounding box.

    By default, padding is 10. The range of the slider is reduced from padding * 2 on the screen. It allow to draw a cursor of 20px width, without having the cursor going out of the widget.

    `padding` is a `NumericProperty`, default to 10.

  `range`

    Range of the slider, in the format (minimum value, maximum value).

        >>> slider = Slider(min=10, max=80)
        >>> slider.range
        [10, 80]
        >>> slider.range = (20, 100)
        >>> slider.min
        20
        >>> slider.max
        100

    `range` is a `ReferenceListProperty` of (`min`, `max`)

  `value`

    Current value used for the slider.

    `value` is a `NumericProperty`, default to 0.

  `value_normalized`

    Normalized value inside the `range` (min/max) to 0-1 range.

        >>> slider = Slider(value=50, min=0, max=100)
        >>> slider.value
        50
        >>> slider.value_normalized
        0.5
        >>> slider.value = 0
        >>> slider.value_normalized
        0
        >>> slider.value = 1
        >>> slider.value_normalized
        1

    You can also use it for setting the real value without knowing the minimum and maximum.

        >>> slider = Slider(min=0, max=200)
        >>> slider.value_normalized = .5
        >>> slider.value
        100
        >>> slider.value_normalized = 1.
        >>> slider.value
        200

    `value_normalized` is an `AliasProperty`.

  `value_pos`

    Position of the internal cursor, based on the normalized value.

    `value_pos` is an `AliasProperty`.